@@ -1,8 +1,9 @@
+from django.http import HttpRequest
 from django.urls import reverse
 from django.urls.exceptions import NoReverseMatch
 
 
-def get_client_ip(request):
+def get_client_ip(request: HttpRequest) -> str:
     x_forwarded_for = request.META.get('HTTP_X_FORWARDED_FOR')
     if x_forwarded_for:
         ip = x_forwarded_for.split(',')[0]
@@ -11,7 +12,7 @@ def get_client_ip(request):
     return ip
 
 
-def get_url_path(url):
+def get_url_path(url: str) -> str:
     """
     url can either be a url name or a url path. First try and reverse a URL,
     if this does not exist then assume it's a url path
